@@ -1,5 +1,5 @@
 package DateTime::Format::EraLegis;
-$DateTime::Format::EraLegis::VERSION = '0.010';
+$DateTime::Format::EraLegis::VERSION = '0.011';
 # ABSTRACT: DateTime formatter for Era Legis (http://oto-usa.org/calendar.html)
 
 use 5.010;
@@ -86,7 +86,7 @@ no Any::Moose;
 
 ######################################################
 package DateTime::Format::EraLegis::Ephem;
-$DateTime::Format::EraLegis::Ephem::VERSION = '0.010';
+$DateTime::Format::EraLegis::Ephem::VERSION = '0.011';
 use Any::Moose qw(Role);
 
 requires 'lookup';
@@ -95,7 +95,7 @@ no Any::Moose;
 
 ######################################################
 package DateTime::Format::EraLegis::Ephem::DBI;
-$DateTime::Format::EraLegis::Ephem::DBI::VERSION = '0.010';
+$DateTime::Format::EraLegis::Ephem::DBI::VERSION = '0.011';
 use 5.010;
 use Any::Moose;
 use Carp;
@@ -144,7 +144,7 @@ no Any::Moose;
 ######################################################
 
 package DateTime::Format::EraLegis::Style;
-$DateTime::Format::EraLegis::Style::VERSION = '0.010';
+$DateTime::Format::EraLegis::Style::VERSION = '0.011';
 use 5.010;
 use Any::Moose;
 use utf8;
@@ -239,7 +239,7 @@ method _build_template {
         $template = "☉$vs in {sdeg}° {ssign} : ☽$vs in {ldeg}° {lsign}";
     }
     else {
-        $template = '☉$vs in {ssign} : ☽$vs in {lsign}';
+        $template = "☉$vs in {ssign} : ☽$vs in {lsign}";
     }
     if ($self->show_terse) {
         $template =~ s/ in / /g;
